@@ -3,7 +3,7 @@ use strict;
 package Parse::CPAN::Meta;
 # ABSTRACT: Parse META.yml and META.json CPAN metadata files
 
-our $VERSION = '1.4419'; # TRIAL
+our $VERSION = '1.4420'; # TRIAL
 
 use Exporter;
 use Carp 'croak';
@@ -93,8 +93,8 @@ sub json_backend {
     return $backend;
   }
   if (! $ENV{PERL_JSON_BACKEND} or $ENV{PERL_JSON_BACKEND} eq 'JSON::PP') {
-    _can_load( 'JSON::PP' => 2.27103 )
-      or croak "JSON::PP 2.27103 is not available\n";
+    _can_load( 'JSON::PP' => 2.27300 )
+      or croak "JSON::PP 2.27300 is not available\n";
     return 'JSON::PP';
   }
   else {
@@ -157,7 +157,7 @@ Parse::CPAN::Meta - Parse META.yml and META.json CPAN metadata files
 
 =head1 VERSION
 
-version 1.4419
+version 1.4420
 
 =head1 SYNOPSIS
 
@@ -337,7 +337,7 @@ will be thrown.
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/Perl-ToolChain-Gang/Parse-CPAN-Meta/issues>.
+at L<https://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -345,9 +345,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/Perl-ToolChain-Gang/Parse-CPAN-Meta>
+L<https://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta>
 
-  git clone https://github.com/Perl-ToolChain-Gang/Parse-CPAN-Meta.git
+  git clone https://github.com/Perl-Toolchain-Gang/Parse-CPAN-Meta.git
 
 =head1 AUTHORS
 
@@ -365,12 +365,20 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Graham Knop Joshua ben Jore Karen Etheridge Matt S Trout Neil Bowers Ricardo Signes Steffen Mueller
+=for stopwords Andreas Koenig David Golden Graham Knop Joshua ben Jore Karen Etheridge Matt S Trout Neil Bowers Ricardo Signes Steffen Mueller
 
 =over 4
 
 =item *
 
+Andreas Koenig <andk@cpan.org>
+
+=item *
+
+David Golden <xdg@xdg.me>
+
+=item *
+
 Graham Knop <haarg@haarg.org>
 
 =item *
